@@ -14,7 +14,7 @@ __all__ = ['NumericKinematics']
 class NumericKinematics(Anisotropy):
 
     def __init__(self, kwargs_model, kwargs_cosmo, interpol_grid_num=1000, log_integration=True, max_integrate=1000,
-                 min_integrate=0.0001, lum_weight_int_method=False):
+                 min_integrate=0.0001, max_light_draw=None, lum_weight_int_method=True):
         """
         What we need:
         - max projected R to have ACCURATE I_R_sigma values
@@ -22,8 +22,10 @@ class NumericKinematics(Anisotropy):
 
         :param interpol_grid_num: number of interpolation bins for integrand and interpolated functions
         :param log_integration: bool, if True, performs the numerical integral in log space distance (adviced)
+         (only applies for lum_weight_int_method=True)
         :param max_integrate: maximum radius (in arc seconds) of the Jeans equation integral
          (assumes zero tracer particles outside this radius)
+        :param max_light_draw: float; (optional) if set, draws up to this radius, else uses max_interpolate value
         :param lum_weight_int_method: bool, luminosity weighted dispersion integral to calculate LOS projected Jean's
          solution. ATTENTION: currently less accurate than 3d solution
         :param min_integrate:
@@ -37,8 +39,11 @@ class NumericKinematics(Anisotropy):
         self._min_integrate = min_integrate  # min integration (and interpolation) in units of arcsecs
         self._max_interpolate = max_integrate  # we chose to set the interpolation range to the integration range
         self._min_interpolate = min_integrate  # we chose to set the interpolation range to the integration range
+        if max_light_draw is None:
+            max_light_draw = max_integrate  # make sure the actual solution for the kinematics is only computed way inside the integral
         self.lightProfile = LightProfile(light_profile_list, interpol_grid_num=interpol_grid_num,
-                                         max_interpolate=max_integrate, min_interpolate=min_integrate)
+                                         max_interpolate=max_integrate, min_interpolate=min_integrate,
+                                         max_draw=max_light_draw)
         Anisotropy.__init__(self, anisotropy_type=anisotropy_model)
         self.cosmo = Cosmo(**kwargs_cosmo)
         self._mass_profile = SinglePlane(mass_profile_list)
@@ -46,26 +51,27 @@ class NumericKinematics(Anisotropy):
 
     def sigma_s2(self, r, R, kwargs_mass, kwargs_light, kwargs_anisotropy):
         """
-        returns unweighted los velocity dispersion for a specified projected radius
+        returns unweighted los velocity dispersion for a specified 3d and projected radius
+        (if lum_weight_int_method=True then the 3d radius is not required and the function directly performs the
+        luminosity weighted integral in projection at R)
 
         :param r: 3d radius (not needed for this calculation)
         :param R: 2d projected radius (in angular units of arcsec)
         :param kwargs_mass: mass model parameters (following lenstronomy lens model conventions)
         :param kwargs_light: deflector light parameters (following lenstronomy light model conventions)
         :param kwargs_anisotropy: anisotropy parameters, may vary according to anisotropy type chosen.
-            We refer to the Anisotropy() class for details on the parameters.
-        :return: line-of-sight projected velocity dispersion at projected radius R
+         We refer to the Anisotropy() class for details on the parameters.
+        :return: weighted line-of-sight projected velocity dispersion at projected radius R with weights I
         """
         if self._lum_weight_int_method is True:
-            return self.sigma_s2_project_int(r, R, kwargs_mass, kwargs_light, kwargs_anisotropy)
+            return self.sigma_s2_project(R, kwargs_mass, kwargs_light, kwargs_anisotropy)
         else:
-            return self.sigma_s2_full(r, R, kwargs_mass, kwargs_light, kwargs_anisotropy)
+            return self.sigma_s2_r(r, R, kwargs_mass, kwargs_light, kwargs_anisotropy), 1
 
-    def sigma_s2_project_int(self, r, R, kwargs_mass, kwargs_light, kwargs_anisotropy):
+    def sigma_s2_project(self, R, kwargs_mass, kwargs_light, kwargs_anisotropy):
         """
-        returns unweighted los velocity dispersion for a specified projected radius
+        returns luminosity-weighted los velocity dispersion for a specified projected radius R and weight
 
-        :param r: 3d radius (not needed for this calculation)
         :param R: 2d projected radius (in angular units of arcsec)
         :param kwargs_mass: mass model parameters (following lenstronomy lens model conventions)
         :param kwargs_light: deflector light parameters (following lenstronomy light model conventions)
@@ -73,16 +79,17 @@ class NumericKinematics(Anisotropy):
             We refer to the Anisotropy() class for details on the parameters.
         :return: line-of-sight projected velocity dispersion at projected radius R
         """
-        # TODO: this is potentially inaccurate as the light-only integral is analytically to infinity while the
         # nominator is numerically to a finite distance, so luminosity weighting might be off
         # this could lead to an under-prediction of the velocity dispersion
-        I_R_sigma2 = self._I_R_sigma2_interp(R, kwargs_mass, kwargs_light, kwargs_anisotropy)
-        I_R = self.lightProfile.light_2d(R, kwargs_light)
-        return np.nan_to_num(I_R_sigma2 / I_R)
+        # so we ask the function _I_R_sigma2() to also return the numerical l(r)
+        #I_R_sigma2, I_R = self._I_R_sigma2_interp(R, kwargs_mass, kwargs_light, kwargs_anisotropy)
+        I_R_sigma2, I_R = self._I_R_sigma2_interp(R, kwargs_mass, kwargs_light, kwargs_anisotropy)
+        #I_R = self.lightProfile.light_2d(R, kwargs_light)
+        return I_R_sigma2 / I_R, 1
 
-    def sigma_s2_full(self, r, R, kwargs_mass, kwargs_light, kwargs_anisotropy):
+    def sigma_s2_r(self, r, R, kwargs_mass, kwargs_light, kwargs_anisotropy):
         """
-        returns unweighted los velocity dispersion for a specified projected radius
+        returns unweighted los velocity dispersion for a specified 3d radius r at projected radius R
 
         :param r: 3d radius (not needed for this calculation)
         :param R: 2d projected radius (in angular units of arcsec)
@@ -112,7 +119,8 @@ class NumericKinematics(Anisotropy):
             We refer to the Anisotropy() class for details on the parameters.
         :return: sigma_r**2
         """
-        l_r = self.lightProfile.light_3d_interp(r, kwargs_light)
+        # l_r = self.lightProfile.light_3d_interp(r, kwargs_light)
+        l_r = self.lightProfile.light_3d(r, kwargs_light)
         f_r = self.anisotropy_solution(r, **kwargs_anisotropy)
         return 1 / f_r / l_r * self._jeans_solution_integral(r, kwargs_mass, kwargs_light, kwargs_anisotropy) * const.G / (const.arcsec * self.cosmo.dd * const.Mpc)
 
@@ -149,12 +157,6 @@ class NumericKinematics(Anisotropy):
         """
         r = self.lightProfile.draw_light_3d(kwargs_light, n=1)[0]
         R, x, y = util.project2d_random(r)
-
-        # this code is a remnant of the 2d-only rendering
-        # (can be used when accurate luminosity-weighted integrated velocity dispersion predictions are made)
-        # R = self.lightProfile.draw_light_2d(kwargs_light, n=1)[0]
-        # x, y = util.draw_xy(R)
-        # r = None
         return r, R, x, y
 
     def delete_cache(self):
@@ -185,18 +187,38 @@ class NumericKinematics(Anisotropy):
         """
         R = max(R, self._min_integrate)
         max_integrate = self._max_integrate  # make sure the integration of the Jeans equation is performed further out than the interpolation
+        #if False:
+        #    # linear integral near R
+        #    lin_max = min(2 * R_, self._max_interpolate)
+        #    lin_max = min(lin_max, R_+1)
+        #    r_array = np.linspace(start=R, stop=lin_max, num=int(self._interp_grid_num / 2))
+        #    dr = r_array[2] - r_array[1]
+        #    IR_sigma2_ = self._integrand_A15(r_array[1:] - dr/2, R, kwargs_mass, kwargs_light, kwargs_anisotropy)
+        #    IR_sigma2_dr_lin = IR_sigma2_ * dr
+        #    # logarithmic integral for larger extent
+        #    max_log = np.log10(max_integrate)
+        #    r_array = np.logspace(np.log10(lin_max), max_log, int(self._interp_grid_num / 2))
+        #    dlog_r = (np.log10(r_array[2]) - np.log10(r_array[1])) * np.log(10)
+        #    IR_sigma2_ = self._integrand_A15(r_array, R_, kwargs_mass, kwargs_light, kwargs_anisotropy)
+        #    IR_sigma2_dr_log = IR_sigma2_ * dlog_r * r_array
+        #    IR_sigma2_dr = np.append(IR_sigma2_dr_lin, IR_sigma2_dr_log)
         if self._log_int is True:
-            min_log = np.log10(R+0.001)
+            min_log = np.log10(R)
             max_log = np.log10(max_integrate)
-            r_array = np.logspace(min_log, max_log, self._interp_grid_num)
+            dlogr = (max_log - min_log) / (self._interp_grid_num - 1)
+            r_array = np.logspace(min_log + dlogr / 2., max_log + dlogr / 2., self._interp_grid_num)
             dlog_r = (np.log10(r_array[2]) - np.log10(r_array[1])) * np.log(10)
-            IR_sigma2_dr = self._integrand_A15(r_array, R, kwargs_mass, kwargs_light, kwargs_anisotropy) * dlog_r * r_array
+            IR_sigma2_ = self._integrand_A15(r_array, R, kwargs_mass, kwargs_light, kwargs_anisotropy)
+            IR_sigma2_dr = IR_sigma2_ * dlog_r * r_array
         else:
-            r_array = np.linspace(R+0.001, max_integrate, self._interp_grid_num)
+            r_array = np.linspace(start=R, stop=self._max_interpolate, num=self._interp_grid_num)
             dr = r_array[2] - r_array[1]
-            IR_sigma2_dr = self._integrand_A15(r_array, R, kwargs_mass, kwargs_light, kwargs_anisotropy) * dr
+            IR_sigma2_ = self._integrand_A15(r_array + dr / 2., R, kwargs_mass, kwargs_light, kwargs_anisotropy)
+            IR_sigma2_dr = IR_sigma2_ * dr
+
         IR_sigma2 = np.sum(IR_sigma2_dr) # integral from angle to physical scales
-        return IR_sigma2 * 2 * const.G / (const.arcsec * self.cosmo.dd * const.Mpc)
+        IR = self.lightProfile.light_2d_finite(R, kwargs_light)
+        return IR_sigma2 * 2 * const.G / (const.arcsec * self.cosmo.dd * const.Mpc), IR
 
     def _I_R_sigma2_interp(self, R, kwargs_mass, kwargs_light, kwargs_anisotropy):
         """
@@ -208,15 +230,20 @@ class NumericKinematics(Anisotropy):
         :param kwargs_anisotropy: stellar anisotropy keyword arguments
         :return:
         """
+        R = np.maximum(R, self._min_integrate)
         if not hasattr(self, '_interp_I_R_sigma2'):
             min_log = np.log10(self._min_integrate)
             max_log = np.log10(self._max_integrate)
-            R_array = np.logspace(min_log, max_log, self._interp_grid_num)
+            R_array = np.logspace(min_log, max_log, self._interp_grid_num)  # self._interp_grid_num
             I_R_sigma2_array = []
+            I_R_array = []
             for R_i in R_array:
-                I_R_sigma2_array.append(self._I_R_sigma2(R_i, kwargs_mass, kwargs_light, kwargs_anisotropy))
+                I_R_sigma2_, IR_ = self._I_R_sigma2(R_i, kwargs_mass, kwargs_light, kwargs_anisotropy)
+                I_R_sigma2_array.append(I_R_sigma2_)
+                I_R_array.append(IR_)
             self._interp_I_R_sigma2 = interp1d(np.log(R_array), np.array(I_R_sigma2_array), fill_value="extrapolate")
-        return self._interp_I_R_sigma2(np.log(R))
+            self._interp_I_R = interp1d(np.log(R_array), np.array(I_R_array), fill_value="extrapolate")
+        return self._interp_I_R_sigma2(np.log(R)), self._interp_I_R(np.log(R))
 
     def _integrand_A15(self, r, R, kwargs_mass, kwargs_light, kwargs_anisotropy):
         """
@@ -228,11 +255,13 @@ class NumericKinematics(Anisotropy):
         :param kwargs_light: deflector light parameters (following lenstronomy light model conventions)
         :param kwargs_anisotropy: anisotropy parameters, may vary according to anisotropy type chosen.
             We refer to the Anisotropy() class for details on the parameters.
-        :return:
+        :return: integrand
         """
         k_r = self.K(r, R, **kwargs_anisotropy)
-        l_r = self.lightProfile.light_3d_interp(r, kwargs_light)
-        m_r = self._mass_3d_interp(r, kwargs_mass)
+        #l_r = self.lightProfile.light_3d_interp(r, kwargs_light)
+        #m_r = self._mass_3d_interp(r, kwargs_mass)
+        l_r = self.lightProfile.light_3d(r, kwargs_light)
+        m_r = self.mass_3d(r, kwargs_mass)
         out = k_r * l_r * m_r / r
         return out
 
@@ -245,7 +274,7 @@ class NumericKinematics(Anisotropy):
         :param kwargs_light: light profile keyword arguments
         :param kwargs_anisotropy: anisotropy keyword arguments
         :return: interpolated solution of the Jeans integral
-         (copped values at large radius as they become numerically inaccurate)
+        (copped values at large radius as they become numerically inaccurate)
         """
         if not hasattr(self, '_interp_jeans_integral'):
             min_log = np.log10(self._min_integrate)
@@ -268,14 +297,14 @@ class NumericKinematics(Anisotropy):
         integrand of A1 (in log space) in Mamon&Lokas 2005 to calculate the Jeans equation numerically
         f(s) l(s) M(s) / s^2
 
-        :param r:
-        :param kwargs_mass:
-        :param kwargs_light:
-        :param kwargs_anisotropy:
-        :return:
+        :param r: 3d radius
+        :param kwargs_mass: mass model keyword arguments
+        :param kwargs_light: light model keyword arguments
+        :param kwargs_anisotropy: anisotropy model keyword argument
+        :return: integrand value
         """
         f_r = self.anisotropy_solution(r, **kwargs_anisotropy)
-        l_r = self.lightProfile.light_3d_interp(r, kwargs_light)
+        l_r = self.lightProfile.light_3d(r, kwargs_light)
         m_r = self._mass_3d_interp(r, kwargs_mass)
         out = f_r * l_r * m_r / r**2
         return out
@@ -291,8 +320,7 @@ class NumericKinematics(Anisotropy):
         if not hasattr(self, '_log_mass_3d') or new_compute is True:
             r_array = np.logspace(np.log10(self._min_interpolate), np.log10(self._max_interpolate), self._interp_grid_num)
             mass_3d_array = self.mass_3d(r_array, kwargs)
-            mass_3d_array[mass_3d_array < 10. ** (-10)] = 10. ** (-10)
-            #mass_dim_array = mass_3d_array * const.arcsec ** 2 * self.cosmo.dd * self.cosmo.ds \
-            #                 / self.cosmo.dds * const.Mpc * const.c ** 2 / (4 * np.pi * const.G)
-            self._log_mass_3d = interp1d(np.log(r_array), np.log(mass_3d_array/r_array), fill_value="extrapolate")
-        return np.exp(self._log_mass_3d(np.log(r))) * r
+            mass_3d_array[mass_3d_array < 10. ** (-100)] = 10. ** (-100)
+            self._log_mass_3d = interp1d(np.log(r_array), np.log(mass_3d_array/r_array),
+                                         fill_value=(np.log(mass_3d_array[0] / r_array[0]), -1000), bounds_error=False)
+        return np.exp(self._log_mass_3d(np.log(r))) * np.minimum(r, self._max_interpolate)
