@@ -1,6 +1,7 @@
 import numpy.testing as npt
 import pytest
 import lenstronomy.Util.data_util as data_util
+import numpy as np
 
 
 def test_absolute2apparent_magnitude():
@@ -26,6 +27,23 @@ def test_magnitude2cps():
     npt.assert_almost_equal(cps, cps_new, decimal=9)
 
 
+def test_bkg_noise():
+
+    readout_noise = 2
+    exposure_time = 100
+    sky_brightness = 0.01
+    pixel_scale = 0.05
+    num_exposures = 10
+    sigma_bkg = data_util.bkg_noise(readout_noise, exposure_time, sky_brightness, pixel_scale, num_exposures=num_exposures)
+
+    exposure_time_tot = num_exposures * exposure_time
+    readout_noise_tot = num_exposures * readout_noise ** 2  # square of readout noise
+    sky_per_pixel = sky_brightness * pixel_scale ** 2
+    sky_brightness_tot = exposure_time_tot * sky_per_pixel
+    sigma_bkg_ = np.sqrt(readout_noise_tot + sky_brightness_tot) / exposure_time_tot
+    npt.assert_almost_equal(sigma_bkg_, sigma_bkg, decimal=8)
+
+
 def test_flux_noise():
     noise = data_util.flux_noise(cps_pixel=10, exposure_time=100)
     npt.assert_almost_equal(noise, 1, decimal=5)
